"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const useQuizResultsLoaded_1 = tslib_1.__importDefault(require("./useQuizResultsLoaded"));
const useQuizResultClick_1 = tslib_1.__importDefault(require("./useQuizResultClick"));
const useQuizAddToCart_1 = tslib_1.__importDefault(require("./useQuizAddToCart"));
const useQuizBackClick_1 = tslib_1.__importDefault(require("./useQuizBackClick"));
const useQuizAnswerChangeHandler_1 = tslib_1.__importDefault(require("./useQuizAnswerChangeHandler"));
const useQuizNextClick_1 = tslib_1.__importDefault(require("./useQuizNextClick"));
const useQuizResetClick_1 = tslib_1.__importDefault(require("./useQuizResetClick"));
const useHydrateQuizLocalState_1 = tslib_1.__importDefault(require("./useHydrateQuizLocalState"));
const utils_1 = require("../../utils");
const useQuizAddToFavorites_1 = tslib_1.__importDefault(require("./useQuizAddToFavorites"));
const useQuizSkipClick_1 = tslib_1.__importDefault(require("./useQuizSkipClick"));
const useQuizEvents = (quizOptions, cioClient, quizState) => {
    const { quizApiState, dispatchLocalState, dispatchApiState, quizLocalState, quizSessionStorageState, } = quizState;
    const { resultsPageOptions, callbacks } = quizOptions;
    const { onAddToCartClick, onQuizResultClick, onQuizResultsLoaded, onAddToFavoritesClick } = resultsPageOptions;
    // Quiz answer change
    const quizAnswerChanged = (0, useQuizAnswerChangeHandler_1.default)(quizApiState, dispatchLocalState);
    // Quiz Next button click callback
    const nextQuestion = (0, useQuizNextClick_1.default)(quizApiState, quizLocalState, dispatchLocalState, callbacks === null || callbacks === void 0 ? void 0 : callbacks.onQuizNextQuestion);
    const skipQuestion = (0, useQuizSkipClick_1.default)(quizApiState, quizLocalState, dispatchLocalState, callbacks === null || callbacks === void 0 ? void 0 : callbacks.onQuizSkipQuestion);
    // Quiz Back button click callback
    const previousQuestion = (0, useQuizBackClick_1.default)(quizApiState, dispatchLocalState);
    // Quiz result add to cart callback
    const addToCart = (0, useQuizAddToCart_1.default)(cioClient, quizApiState, onAddToCartClick);
    // Quiz result click callback
    const resultClick = (0, useQuizResultClick_1.default)(cioClient, quizApiState, onQuizResultClick);
    const addToFavorites = (0, useQuizAddToFavorites_1.default)(cioClient, quizApiState, onAddToFavoritesClick);
    // Quiz results loaded event
    (0, useQuizResultsLoaded_1.default)(cioClient, quizApiState, onQuizResultsLoaded);
    // Quiz reset
    const resetQuiz = (0, useQuizResetClick_1.default)((0, utils_1.resetQuizSessionStorageState)(quizSessionStorageState.key), dispatchLocalState, dispatchApiState, quizApiState.quizResults);
    // Quiz rehydrate
    const hydrateQuizLocalState = (0, useHydrateQuizLocalState_1.default)(quizSessionStorageState.key, dispatchLocalState);
    return {
        addToCart,
        addToFavorites,
        resultClick,
        quizAnswerChanged,
        previousQuestion,
        nextQuestion,
        skipQuestion,
        resetQuiz,
        hydrateQuiz: hydrateQuizLocalState,
        resetSessionStorageState: (0, utils_1.resetQuizSessionStorageState)(quizSessionStorageState.key),
    };
};
exports.default = useQuizEvents;
