"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.trackQuizConversion = exports.trackQuizResultClick = exports.trackQuizResultsLoaded = exports.getQuizResults = exports.getNextQuestion = exports.getCioClient = void 0;
const tslib_1 = require("tslib");
/* eslint-disable @typescript-eslint/naming-convention */
const constructorio_client_javascript_1 = tslib_1.__importDefault(require("@constructor-io/constructorio-client-javascript"));
const package_json_1 = require("../../package.json");
const getCioClient = (apiKey) => {
    if (apiKey) {
        return new constructorio_client_javascript_1.default({
            apiKey,
            sendTrackingEvents: true,
            version: `cio-ui-quizzes-${package_json_1.version}`,
        });
    }
    return undefined;
};
exports.getCioClient = getCioClient;
const getNextQuestion = (cioClient, quizId, parameters) => cioClient === null || cioClient === void 0 ? void 0 : cioClient.quizzes.getQuizNextQuestion(quizId, parameters);
exports.getNextQuestion = getNextQuestion;
const getQuizResults = (cioClient, quizId, parameters) => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return cioClient === null || cioClient === void 0 ? void 0 : cioClient.quizzes.getQuizResults(quizId, parameters); });
exports.getQuizResults = getQuizResults;
// Tracking requests
const trackQuizResultsLoaded = (cioClient, quizResults) => {
    var _a;
    const { quiz_id, quiz_session_id, quiz_version_id, result_id, request, response } = quizResults;
    const items = (_a = response === null || response === void 0 ? void 0 : response.results) === null || _a === void 0 ? void 0 : _a.map((result) => {
        var _a, _b;
        return ({
            itemId: (_a = result === null || result === void 0 ? void 0 : result.data) === null || _a === void 0 ? void 0 : _a.id,
            variationId: (_b = result === null || result === void 0 ? void 0 : result.data) === null || _b === void 0 ? void 0 : _b.variation_id,
            itemName: result === null || result === void 0 ? void 0 : result.value,
        });
    });
    cioClient === null || cioClient === void 0 ? void 0 : cioClient.tracker.trackQuizResultsLoaded({
        quizId: quiz_id,
        quizVersionId: quiz_version_id,
        quizSessionId: quiz_session_id,
        url: window.location.href,
        section: request === null || request === void 0 ? void 0 : request.section,
        resultCount: response === null || response === void 0 ? void 0 : response.total_num_results,
        resultPage: request === null || request === void 0 ? void 0 : request.page,
        resultId: result_id,
        items,
    });
};
exports.trackQuizResultsLoaded = trackQuizResultsLoaded;
const trackQuizResultClick = (cioClient, quizResults, result, position) => {
    var _a;
    if (quizResults.request && quizResults.response) {
        const { quiz_id, quiz_session_id, quiz_version_id, result_id, request: { section, page, num_results_per_page }, response: { total_num_results }, } = quizResults;
        cioClient === null || cioClient === void 0 ? void 0 : cioClient.tracker.trackQuizResultClick({
            quizId: quiz_id,
            quizVersionId: quiz_version_id,
            quizSessionId: quiz_session_id,
            itemId: (_a = result.data) === null || _a === void 0 ? void 0 : _a.id,
            itemName: result === null || result === void 0 ? void 0 : result.value,
            section,
            resultCount: total_num_results,
            resultPage: page,
            resultId: result_id,
            resultPositionOnPage: position,
            numResultsPerPage: num_results_per_page,
        });
    }
};
exports.trackQuizResultClick = trackQuizResultClick;
const trackQuizConversion = (cioClient, quizResults, result, price, type
// eslint-disable-next-line max-params
) => {
    var _a, _b;
    if (quizResults.request) {
        const { quiz_id, quiz_session_id, quiz_version_id, request: { section }, } = quizResults;
        cioClient === null || cioClient === void 0 ? void 0 : cioClient.tracker.trackQuizConversion({
            quizId: quiz_id,
            quizVersionId: quiz_version_id,
            quizSessionId: quiz_session_id,
            itemId: (_a = result.data) === null || _a === void 0 ? void 0 : _a.id,
            itemName: result.value,
            section,
            variationId: (_b = result.data) === null || _b === void 0 ? void 0 : _b.variation_id,
            revenue: (price && String(price)) || undefined,
            type,
        });
    }
};
exports.trackQuizConversion = trackQuizConversion;
